@@ -1,5 +1,5 @@
 createTable <- function(x, hide = NA, digits = NA, type = NA, show.p.overall = TRUE, show.all, show.p.trend, show.p.mul = FALSE, show.n, show.ratio = FALSE, show.descr = TRUE, 
-                        show.ci = FALSE, hide.no = NA, digits.ratio = NA, show.p.ratio = show.ratio, digits.p = 3, sd.type = 1, q.type = c(1,1), extra.labels = NA)
+                        show.ci = FALSE, hide.no = NA, digits.ratio = NA, show.p.ratio = show.ratio, digits.p = 3, sd.type = 1, q.type = c(1,1), extra.labels = NA, all.last = FALSE)
 {
   
   os<-sessionInfo()$platform
@@ -220,6 +220,8 @@ createTable <- function(x, hide = NA, digits = NA, type = NA, show.p.overall = T
   attr(ans,"x")<-list(x)
   attr(ans,"Xlong")<-attr(x,"Xlong")
   attr(ans,"ylong")<-attr(x,"ylong")  
+  
+  attr(ans,"all.last")<-all.last
       
   if (!is.null(elim.pos))
     ans[[1]]<-ans[[1]][,-elim.pos,drop=FALSE]
